@@ -76,6 +76,18 @@ class Poll(object):
             if to_mask:
                 self._poller.register(fd, to_mask)
 
+    def supports(self, fd):
+        if not isinstance(fd, int):
+            fd = fd.fileno()
+
+        try:
+            self._poller.register(fd)
+        except EnvironmentError:
+            return False
+
+        self._poller.unregister(fd)
+        return True
+
 
 class Epoll(Poll):
     "a greenhouse poller utilizing the 2.6+ stdlib's epoll support"
@@ -205,6 +217,10 @@ class Select(object):
             events[fd] |= self.ERRMASK
         return events.items()
 
+    def supports(self, fd):
+        # it might lie though
+        return True
+
 
 def best():
     if hasattr(select, 'epoll'):
